import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import React from "react";
import "./registeredComponents/loader";
import "./registeredThemes/loader";
import { Box } from "@chakra-ui/react";
import { RuntimeContext } from "@qorebase/app-component";
import RuntimeTheme from "./RuntimeTheme";
import RuntimeContents from "./RuntimeContents";
import { Composer } from "./Composer";
import { importCustomComponent, importLocalNpmComponent, importNpmComponent, listLocalComponents, } from "./utils/importComponent";
import { getBuiltinImporters } from "./builtinComponents";
export default React.memo(function Runtime() {
    const components = RuntimeContext.useSelectState((state) => state.app.maps.component);
    const npmComponents = RuntimeContext.useSelectState((state) => state.app.components);
    // prefetch all custom components
    React.useEffect(() => {
        (Object.values(components) || [])
            .reduce((urls, component) => component.metadata.componentURL
            ? urls.concat(component.metadata.componentURL)
            : urls, [])
            .map((url) => importCustomComponent(url));
        const usedComponents = [
            ...new Set(Object.values(components).map((component) => component.componentID)),
        ] || [];
        // TODO: temporary prefetch npm component in runtime
        const enabledComponents = npmComponents.filter((npmComponent) => npmComponent.enabled);
        enabledComponents.map((npmComponent) => importNpmComponent(npmComponent.name, npmComponent.version));
        listLocalComponents().map(importLocalNpmComponent);
        const { importUsedBuiltinComponents } = getBuiltinImporters(usedComponents, enabledComponents.map((c) => c.name));
        importUsedBuiltinComponents();
    }, []);
    return (_jsx(RuntimeTheme, { children: _jsx(Composer, { children: _jsx(Box, Object.assign({ overflow: "unset", bg: "brand.900" }, { children: _jsx(Box, Object.assign({ overflow: "unset" }, { children: _jsx(RuntimeContents, {}) })) })) }) }));
});
//# sourceMappingURL=Runtime.js.map